"""
TODO: write doc
"""
__title__ = "FLI camera modules"

from .flicamera import FliCamera


__all__ = ["FliCamera"]
